-------------------------------------------------------------------------------
--|> SPLASH SCREEN
--: Creates a splash screen window for a static display of info
-------------------------------------------------------------------------------
--|> UPVALUE GLOBALS
-------------------------------------------------------------------------------
local weizPVP = weizPVP
local CreateFrame = CreateFrame
local UIFrameFadeOut = UIFrameFadeOut
local UIFrameFadeIn = UIFrameFadeIn
local C_Timer = C_Timer
local math = math

-------------------------------------------------------------------------------
--|> LIBS
-------------------------------------------------------------------------------
local SM = LibStub:GetLibrary("LibSharedMedia-3.0")

-------------------------------------------------------------------------------
--|> GLOBAL FUNCTIONS
-------------------------------------------------------------------------------
--> Splash Frame Generate
-------------------------------------------------------------------------------

local SplashDetailsText = "|cff37ff37 Stealth Alerts and Detection|r\n"
SplashDetailsText = SplashDetailsText .. "    - Visual Updates\n"
SplashDetailsText = SplashDetailsText .. "    - Alerts are now shown on the status bar as well\n"
SplashDetailsText = SplashDetailsText .. "\n|cff37ff37 Crosshairs|r\n"
SplashDetailsText = SplashDetailsText .. "    - Recreated higher resolution image assets for sharper scaling.\n"
SplashDetailsText = SplashDetailsText .. "    - More options added\n"
SplashDetailsText = SplashDetailsText .. "    - Name and Guild text added back as Crosshair options\n"
SplashDetailsText = SplashDetailsText .. "    - Toggle Crosshairs On/Off with: |cffffa012/wpvp ch|r\n"
SplashDetailsText = SplashDetailsText .. "    - Toggle Crosshairs keybind added (Main Menu > Keybindings > Addons)\n"
SplashDetailsText = SplashDetailsText .. "\n|cff37ff37 Interface and Media|r\n"
SplashDetailsText = SplashDetailsText .. "    - Multiple UI adjustments (colors/animations/fonts/etc)\n"
SplashDetailsText = SplashDetailsText .. "    - 'MLG Air Horn' sound effect added. Available in audio-related options.\n"
SplashDetailsText = SplashDetailsText .. "\n|cff37ff37 Fixes|r\n"
SplashDetailsText = SplashDetailsText .. "    - Resolved issue for some where the window wouldnt save position.\n"
SplashDetailsText = SplashDetailsText .. "    - Many smaller issues fixed or optimized more like they should.\n"

function weizPVP:CreateSplashScreen()
	--> CREATE SPLASH WINDOW
	local f = CreateFrame("Frame", "weizPVPSplashScreen", UIParent)
	f:SetFrameStrata("MEDIUM")
	f:SetPoint("TOP", 0, UIParent:GetTop() - 300)
	f:SetWidth(500)
	f:SetBackdrop(
		{
			bgFile = SM:Fetch("background", "weizPVP: #FFFFFF"),
			tile = false,
			edgeFile = SM:Fetch("border", "weizPVP: Border"),
			edgeSize = 2,
			insets = {left = 2, right = 2, top = 2, bottom = 2}
		}
	)
	f:SetBackdropColor(0.1, 0.1, 0.1, 0.8)
	f:SetBackdropBorderColor(0, 0, 0, 1)
	f:SetClampedToScreen(true)
	f:SetMovable(true)
	f:EnableMouse(true)
	f:RegisterForDrag("LeftButton")
	f:SetDontSavePosition(true)
	f:SetScript(
		"OnDragStart",
		function()
			f:StartMoving()
		end
	)
	f:SetScript(
		"OnDragStop",
		function()
			f:StopMovingOrSizing()
		end
	)
	f:Hide()

	--=> CinModelBG
	-----------------------------------------------------------
	f.pepe = CreateFrame("CinematicModel", "splash pepe", f)
	f.pepe:SetFrameStrata("MEDIUM")
	f.pepe:SetSize(100, 100)
	f.pepe:SetFrameLevel(0)
	f.pepe:SetModelDrawLayer("ARTWORK", 1)
	f.pepe:SetParent(f)
	f.pepe:SetPoint("BOTTOMRIGHT", f, "TOPRIGHT", 0, -28)
	f.pepe:SetModel("world/expansion06/doodads/dalaran/7dl_dalaran_orangebird.m2")
	f.pepe:RefreshUnit()
	f.pepe:ClearTransform()
	f.pepe:SetModelScale(2)
	f.pepe:SetPitch(-0.25)
	f.pepe:SetLight(true, false, -1, 0, 0, .7, .7, .7, .7, .6, 1, 1, 1)
	f.pepe.BG = f:CreateTexture(nil, "BACKGROUND")
	f.pepe.BG:SetPoint("CENTER", f.pepe, "CENTER")
	f.pepe.BG:SetHeight(80)
	f.pepe.BG:SetWidth(80)
	f.pepe.BG:SetDrawLayer("BACKGROUND", 0)
	f.pepe.BG:SetTexture([[Interface\GLUES\Models\UI_NightborneElf\rg_shadow_elf]])
	f.pepe.BG:SetVertexColor(0, 0, 0, 1)
	f.pepe.BG:SetRotation(math.pi)
	f.pepe.BG:SetBlendMode("BLEND")

	--> RECENT CHANGES
	f.wpvp = f:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	f.wpvp:SetFont(SM:Fetch("font", "Roboto Condensed BoldItalic"), 26, "OUTLINE")
	f.wpvp:SetPoint("TOPLEFT", f, "TOPLEFT", 14, -14)
	f.wpvp:SetHeight(26)
	f.wpvp:SetText("|cffffffffweiz|r|cffffa012PVP|r")

	f.recent = f:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	f.recent:SetFont(SM:Fetch("font", "Roboto Condensed Bold"), 26, "OUTLINE")
	f.recent:SetPoint("LEFT", f.wpvp, "RIGHT", 0, 0)
	f.recent:SetHeight(26)
	f.recent:SetText(": |cff42dcf4RECENT CHANGES|r")

	--> VERSION
	f.version = f:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	f.version:SetPoint("TOPRIGHT", f, "TOPRIGHT", 0, -12)
	f.version:SetJustifyH("RIGHT")
	f.version:SetFont(SM:Fetch("font", "Roboto Condensed Bold"), 12, "NONE")
	f.version:SetText("|cffeeeeee" .. weizPVP.Addon.VERSION .. "|r  ")

	--> CHANGELOG
	f.changes = f:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	f.changes:SetPoint("TOPLEFT", f.wpvp, "BOTTOMLEFT", 0, -8)
	f.changes:SetFont(SM:Fetch("font", "Roboto Condensed Bold"), 14, "OUTLINE")
	f.changes:SetWidth(480)
	f.changes:SetSpacing(1)
	f.changes:SetJustifyH("LEFT")
	f.changes:SetText(SplashDetailsText)

	f.bg = f:CreateTexture(nil, "BACKGROUND")
	f.bg:SetPoint("TOPLEFT", f, "TOPLEFT")
	f.bg:SetPoint("BOTTOMRIGHT", f, "BOTTOMRIGHT")
	f.bg:SetDrawLayer("BACKGROUND", 0)
	f.bg:SetColorTexture(0, 0, 0, 1)
	f.bg:SetGradientAlpha("VERTICAL", 0.1, 0.1, 0.1, 0.2, 0.1, 0.1, 0.1, 0.8)

	--> OK BUTTON
	f.okayButton = CreateFrame("Button", "weizPVP: Splash OK Button", f)
	f.okayButton:SetSize(160, 32)
	f.okayButton:SetPoint("TOP", f.changes, "BOTTOM", 0, -20)
	f.okayButton:SetBackdrop(
		{
			bgFile = SM:Fetch("background", "weizPVP: #FFFFFF"),
			tile = false,
			edgeFile = SM:Fetch("border", "weizPVP: Border"),
			edgeSize = 1,
			insets = {left = 2, right = 2, top = 2, bottom = 2}
		}
	)
	f.okayButton:SetBackdropColor(0.4, 0.4, 0.4, 1)
	f.okayButton:SetBackdropBorderColor(0, 0, 0, 1)
	f.okayButton:SetScript(
		"OnClick",
		function()
			--> CLEAN ALL SETTINGS
			f:SetMovable(false)
			f:EnableMouse(false)
			f.okayButton:EnableMouse(false)
			--> Fade out
			UIFrameFadeOut(f, 0.2, 1, 0)
			C_Timer.After(
				0.2,
				function()
					f = nil
				end
			)
			weizPVP.Options.Addon.VersionSplashSeen = true
		end
	)

	--> OK TEXT
	f.okayButton.text = f.okayButton:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	f.okayButton.text:SetPoint("CENTER")
	f.okayButton.text:SetJustifyH("CENTER")
	f.okayButton.text:SetTextColor(1, 1, 1, 1)
	f.okayButton.text:SetText("OK")
	f.okayButton.text:SetShadowOffset(1, -1)
	f.okayButton.text:SetFont(SM:Fetch("font", "Roboto Condensed Bold"), 20, "OUTLINE")
	f.okayButton:SetScript(
		"OnEnter",
		function()
			f.okayButton.text:SetShadowOffset(2, -2)
			f.okayButton:SetBackdropColor(0.7, 0.7, 0.7, 1)
		end
	)
	f.okayButton:SetScript(
		"OnLeave",
		function()
			f.okayButton.text:SetShadowOffset(1, -1)
			f.okayButton:SetBackdropColor(0.4, 0.4, 0.4, 1)
		end
	)

	f:SetHeight(56 + f.changes:GetHeight() + f.okayButton:GetHeight() + f.recent:GetHeight())
	f:ClearAllPoints()
	f:SetPoint("CENTER", UIParent, "CENTER", 0, (f:GetHeight() / 3))
	f.okayButton:SetWidth(f:GetWidth() - 40)

	weizPVP.splash = f
	--> Set Frame position if using older options
	if weizPVP.Options.Addon.VersionSplashSeen == false then
		weizPVP.CoreFrame:ClearAllPoints()
		weizPVP.CoreFrame:SetPoint("TOPLEFT", weizPVP.splash, "TOPRIGHT", 6, -weizPVP.Options.Frames.Header.Height)
		weizPVP.HeaderFrame:ClearAllPoints()
		weizPVP.HeaderFrame:SetPoint("BOTTOM", weizPVP.CoreFrame, "TOP")
		weizPVP.HeaderFrame:SetPoint("LEFT", weizPVP.CoreFrame, "LEFT")
		weizPVP.HeaderFrame:SetPoint("RIGHT", weizPVP.CoreFrame, "RIGHT")
		weizPVP:SaveCoreFramePosition()
	end
	if not weizPVP.Options.Frames.Header.Point then
		weizPVP.CoreFrame:SetPoint("TOPLEFT", UIParent, "BOTTOMLEFT", weizPVP.Options.Frames.X, weizPVP.Options.Frames.Y)
		weizPVP.HeaderFrame:ClearAllPoints()
		weizPVP.HeaderFrame:SetPoint("BOTTOMLEFT", weizPVP.CoreFrame, "TOPLEFT")
		weizPVP.HeaderFrame:SetPoint("BOTTOMRIGHT", weizPVP.CoreFrame, "TOPRIGHT")
		weizPVP.CoreFrame:SetWidth(weizPVP.Options.Frames.Width)
		weizPVP.CoreFrame:SetHeight(weizPVP.Options.Frames.Height)
		weizPVP:SaveCoreFramePosition()
	end
end

-------------------------------------------------------------------------------
--> Check Splash
-------------------------------------------------------------------------------
function weizPVP:CheckSplash()
	--> Reset if not seen splash screen before
	if not weizPVP.Options.Addon.VersionSplashSeen or weizPVP.Options.Addon.VersionSplashSeen == false then
		--> LOAD CHARACTER OPTIONS
		weizPVP.charDB:ResetDB()
		weizPVP.globalDB:ResetDB()
		weizPVP.charDB = LibStub("AceDB-3.0"):New("weizPVPOptions", weizPVP.defaults, true)
		weizPVP.Options = weizPVP.charDB.profile.Options
		--> LOAD GLOBAL PLAYER DB
		weizPVP.globalDB = LibStub("AceDB-3.0"):New("weizPVPDatabase", {}, false)
		weizPVP.PlayerDB = weizPVP.globalDB.global
	end

	--> Check to see if new version popup has been seen for this version
	local ShowSplash = not weizPVP.Options.Addon.VersionNumber or false
	ShowSplash = ShowSplash or weizPVP.Options.Addon.VersionNumber < weizPVP.Addon.SPLASH_SCREEN_FOR_VERSIONS_UNDER
	ShowSplash = ShowSplash or weizPVP.Options.DEBUG == true
	if ShowSplash then
		UIFrameFadeIn(weizPVP.splash, 0.2, 0, 1)
	else
		weizPVP.splash = nil
	end

	--> Update Versions
	weizPVP.Options.Addon.Version = weizPVP.Addon.VERSION
	weizPVP.Options.Addon.VersionNumber = weizPVP.Addon.VERSION_NUM
end
